@@ -1,13 +1,13 @@
 from .queue import Queue
 from .job import Job
-from typing import Type, Union, Tuple
+from typing import Type, Union, Tuple, Callable
 from time import sleep
 from threading import Thread
 import importlib
 
 class Worker:
 
-  def __init__(self, queues: Union[Tuple[Queue,...], Type[Queue]], channel: Union[Tuple[str,...], str]=None, heart_beat: int = 1) -> None:
+  def __init__(self, queues: Union[Tuple[Queue,...], Type[Queue]], channel: Union[Tuple[str,...], str]=None, heart_beat: int = 1, verbosity: str = "error", logger: Union[str, Callable] = None ) -> None:
     
     if isinstance(queues, tuple) or isinstance(queues, list):
       self.queues = queues
@@ -25,6 +25,28 @@ class Worker:
     self._heart_beat = heart_beat
     self._running = False
 
+    self._verbosity = verbosity
+    self.setLogger(logger)
+    
+  def setLogger(self, logger: Union[str, Callable]):
+    if callable(logger):
+      self._logger = logger
+    elif isinstance(logger, str):
+      callback = str(logger)
+      if str(callback).__contains__("."):
+        mod_name, func_name = callback.rsplit(".", 1)
+        mod = importlib.import_module(mod_name)
+        func = getattr(mod, func_name)
+        self._logger = func
+      elif callback in globals():
+        func = globals()[callback]
+        self._logger = func
+    else:
+      self._logger = None
+
+  def setVerbosity(self, verbosity: str):
+    self.verbosity = verbosity
+
   def start(self):
     self._running = True
     self._run()
@@ -57,8 +79,10 @@ class Worker:
     else:
       self._working = False
 
-  def _run_job(self, job):
+  def _run_job(self, job: Type[Job]):
     payload = job.payload
+    job.setVerbosity(self._verbosity)
+    job.setLogger(self._logger)
     try:
       if not payload is None:
         callback = payload.get("function_name")
